==> spring-webmvc-4.2.0.RELEASE-sources.jar: org/springframework/web/servlet/tags/ArgumentTag.java <==
/*
 * Copyright 2002-2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.web.servlet.tags;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyTagSupport;

/**
 * JSP tag for collecting arguments and passing them to an {@link ArgumentAware} ancestor
 * in the tag hierarchy.
 *
 * <p>This tag must be nested under an argument aware tag.
 *
 * @author Nicholas Williams
 * @since 4.0
 * @see MessageTag
 * @see ThemeTag
 */
@SuppressWarnings("serial")
public class ArgumentTag extends BodyTagSupport {

	private Object value;

	private boolean valueSet;

	// tag lifecycle

	@Override
	public int doEndTag() throws JspException {
		Object argument = null;
		if (this.valueSet) {
			argument = this.value;
		}
		else if (getBodyContent() != null) {
			// get the value from the tag body
			argument = getBodyContent().getString().trim();
		}

		// find a param aware ancestor
		ArgumentAware argumentAwareTag = (ArgumentAware) findAncestorWithClass(this,
				ArgumentAware.class);
		if (argumentAwareTag == null) {
			throw new JspException(
					"The argument tag must be a descendant of a tag that supports arguments");
		}

		argumentAwareTag.addArgument(argument);

		return EVAL_PAGE;
	}

	// tag attribute mutators

	/**
	 * Sets the value of the argument
	 *
	 * <p>
	 * Optional. If not set, the tag's body content is evaluated.
	 *
	 * @param value the parameter value
	 */
	public void setValue(Object value) {
		this.value = value;
		this.valueSet = true;
	}

	@Override
	public void release() {
		super.release();
		this.value = null;
		this.valueSet = false;
	}

}

==> spring-webmvc-5.0.0.RELEASE-sources.jar: org/springframework/web/servlet/tags/ArgumentTag.java <==
/*
 * Copyright 2002-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.web.servlet.tags;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyTagSupport;

import org.springframework.lang.Nullable;

/**
 * JSP tag for collecting arguments and passing them to an {@link ArgumentAware}
 * ancestor in the tag hierarchy.
 *
 * <p>This tag must be nested under an argument aware tag.
 *
 * @author Nicholas Williams
 * @since 4.0
 * @see MessageTag
 * @see ThemeTag
 */
@SuppressWarnings("serial")
public class ArgumentTag extends BodyTagSupport {

	@Nullable
	private Object value;

	private boolean valueSet;


	/**
	 * Set the value of the argument (optional).
	 * <pIf not set, the tag's body content will get evaluated.
	 * @param value the parameter value
	 */
	public void setValue(Object value) {
		this.value = value;
		this.valueSet = true;
	}


	@Override
	public int doEndTag() throws JspException {
		Object argument = null;
		if (this.valueSet) {
			argument = this.value;
		}
		else if (getBodyContent() != null) {
			// Get the value from the tag body
			argument = getBodyContent().getString().trim();
		}

		// Find a param-aware ancestor
		ArgumentAware argumentAwareTag = (ArgumentAware) findAncestorWithClass(this, ArgumentAware.class);
		if (argumentAwareTag == null) {
			throw new JspException("The argument tag must be a descendant of a tag that supports arguments");
		}
		argumentAwareTag.addArgument(argument);

		return EVAL_PAGE;
	}

	@Override
	public void release() {
		super.release();
		this.value = null;
		this.valueSet = false;
	}

}
